==> jc-1.4.0.tar.gz: java/awt/RenderingHints__24Key.h <==
// public abstract class java.awt.RenderingHints$Key

// class file dependencies
// @dep_class 77c41ec805713aab java_awt_RenderingHints__24Key
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_RenderingHints__24Key_H_
#define _JC_java_awt_RenderingHints__24Key_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_awt_RenderingHints__24Key$sub_refs	_jc_java_awt_RenderingHints__24Key$sub_refs;
typedef struct _jc_java_awt_RenderingHints__24Key$sub_nonrefs	_jc_java_awt_RenderingHints__24Key$sub_nonrefs;
typedef struct _jc_java_awt_RenderingHints__24Key$refs	_jc_java_awt_RenderingHints__24Key$refs;
typedef struct _jc_java_awt_RenderingHints__24Key$nonrefs	_jc_java_awt_RenderingHints__24Key$nonrefs;
typedef struct _jc_java_awt_RenderingHints__24Key$object	_jc_java_awt_RenderingHints__24Key$object;

typedef const struct _jc_java_awt_RenderingHints__24Key$vmethods	_jc_java_awt_RenderingHints__24Key$vmethods;
typedef const struct _jc_java_awt_RenderingHints__24Key$vtable	_jc_java_awt_RenderingHints__24Key$vtable;
typedef const struct _jc_java_awt_RenderingHints__24Key$vtype	_jc_java_awt_RenderingHints__24Key$vtype;

// Constructors
extern void _jc_java_awt_RenderingHints__24Key$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_RenderingHints__24Key$object *, jint);

// Virtual methods
extern jboolean _jc_java_awt_RenderingHints__24Key$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_awt_RenderingHints__24Key$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_awt_RenderingHints__24Key$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_awt_RenderingHints__24Key$object *);
extern jint _jc_java_awt_RenderingHints__24Key$method$intKey$52ed2839a389d2c8(_jc_env *, struct _jc_java_awt_RenderingHints__24Key$object *);
extern jboolean _jc_java_awt_RenderingHints__24Key$method$isCompatibleValue$9be6507832efe36e(_jc_env *, struct _jc_java_awt_RenderingHints__24Key$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_RenderingHints__24Key$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_awt_RenderingHints__24Key$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_awt_RenderingHints__24Key$method_info$intKey$52ed2839a389d2c8;
extern _jc_method _jc_java_awt_RenderingHints__24Key$method_info$isCompatibleValue$9be6507832efe36e;

// Virtual methods structure
struct _jc_java_awt_RenderingHints__24Key$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_awt_RenderingHints__24Key$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_awt_RenderingHints__24Key$object *);
	jint	(*intKey$52ed2839a389d2c8)(_jc_env *, struct _jc_java_awt_RenderingHints__24Key$object *);
	jboolean	(*isCompatibleValue$9be6507832efe36e)(_jc_env *, struct _jc_java_awt_RenderingHints__24Key$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_java_awt_RenderingHints__24Key$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_RenderingHints__24Key$vmethods	java_awt_RenderingHints__24Key;
};

// Vtype
struct _jc_java_awt_RenderingHints__24Key$vtype {
	_jc_type			type;
	_jc_java_awt_RenderingHints__24Key$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_RenderingHints__24Key$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_RenderingHints__24Key$refs {
    _jc_java_awt_RenderingHints__24Key$sub_refs	java_awt_RenderingHints__24Key;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_RenderingHints__24Key$sub_nonrefs {
	jint	key;
};

// Non-reference instance fields (object)
struct _jc_java_awt_RenderingHints__24Key$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_RenderingHints__24Key$sub_nonrefs	java_awt_RenderingHints__24Key;
};

// Object instance structure
struct _jc_java_awt_RenderingHints__24Key$object {
	_jc_java_awt_RenderingHints__24Key$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_RenderingHints__24Key$vtype	*vtype;
	_jc_java_awt_RenderingHints__24Key$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_RenderingHints__24Key$vtype _jc_java_awt_RenderingHints__24Key$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_RenderingHints__24Key, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_RenderingHints__24Key$class_object;

#endif	/* _JC_java_awt_RenderingHints__24Key_H_ */

==> jc-1.4.6.tar.gz: java/awt/RenderingHints__24Key.h <==
// public abstract class java.awt.RenderingHints$Key

// class file dependencies
// @dep_class 77c41ec805713aab java_awt_RenderingHints__24Key
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_RenderingHints__24Key_H_
#define _JC_java_awt_RenderingHints__24Key_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_awt_RenderingHints__24Key$sub_refs	_jc_java_awt_RenderingHints__24Key$sub_refs;
typedef struct _jc_java_awt_RenderingHints__24Key$sub_nonrefs	_jc_java_awt_RenderingHints__24Key$sub_nonrefs;
typedef struct _jc_java_awt_RenderingHints__24Key$refs	_jc_java_awt_RenderingHints__24Key$refs;
typedef struct _jc_java_awt_RenderingHints__24Key$nonrefs	_jc_java_awt_RenderingHints__24Key$nonrefs;
typedef struct _jc_java_awt_RenderingHints__24Key$object	_jc_java_awt_RenderingHints__24Key$object;

typedef const struct _jc_java_awt_RenderingHints__24Key$vmethods	_jc_java_awt_RenderingHints__24Key$vmethods;
typedef const struct _jc_java_awt_RenderingHints__24Key$vtable	_jc_java_awt_RenderingHints__24Key$vtable;
typedef const struct _jc_java_awt_RenderingHints__24Key$vtype	_jc_java_awt_RenderingHints__24Key$vtype;

// Constructors
extern void _jc_java_awt_RenderingHints__24Key$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_RenderingHints__24Key$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_awt_RenderingHints__24Key$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_awt_RenderingHints__24Key$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_RenderingHints__24Key$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_awt_RenderingHints__24Key$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_RenderingHints__24Key$method$intKey$52ed2839a389d2c8(_jc_env *, struct _jc_java_awt_RenderingHints__24Key$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_RenderingHints__24Key$method$isCompatibleValue$9be6507832efe36e(_jc_env *, struct _jc_java_awt_RenderingHints__24Key$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_RenderingHints__24Key$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_awt_RenderingHints__24Key$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_awt_RenderingHints__24Key$method_info$intKey$52ed2839a389d2c8;
extern _jc_method _jc_java_awt_RenderingHints__24Key$method_info$isCompatibleValue$9be6507832efe36e;

// Virtual methods structure
struct _jc_java_awt_RenderingHints__24Key$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_awt_RenderingHints__24Key$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_awt_RenderingHints__24Key$object *) _JC_JCNI_ATTR;
	jint	(*intKey$52ed2839a389d2c8)(_jc_env *, struct _jc_java_awt_RenderingHints__24Key$object *) _JC_JCNI_ATTR;
	jboolean	(*isCompatibleValue$9be6507832efe36e)(_jc_env *, struct _jc_java_awt_RenderingHints__24Key$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_RenderingHints__24Key$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_RenderingHints__24Key$vmethods	java_awt_RenderingHints__24Key;
};

// Vtype
struct _jc_java_awt_RenderingHints__24Key$vtype {
	_jc_type			type;
	_jc_java_awt_RenderingHints__24Key$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_RenderingHints__24Key$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_RenderingHints__24Key$refs {
    _jc_java_awt_RenderingHints__24Key$sub_refs	java_awt_RenderingHints__24Key;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_RenderingHints__24Key$sub_nonrefs {
	jint	key;
};

// Non-reference instance fields (object)
struct _jc_java_awt_RenderingHints__24Key$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_RenderingHints__24Key$sub_nonrefs	java_awt_RenderingHints__24Key;
};

// Object instance structure
struct _jc_java_awt_RenderingHints__24Key$object {
	_jc_java_awt_RenderingHints__24Key$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_RenderingHints__24Key$vtype	*vtype;
	_jc_java_awt_RenderingHints__24Key$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_RenderingHints__24Key$vtype _jc_java_awt_RenderingHints__24Key$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_RenderingHints__24Key, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_RenderingHints__24Key$class_object;

#endif	/* _JC_java_awt_RenderingHints__24Key_H_ */
